@@ -60,6 +60,7 @@ new ApiGatewayToKinesisStreams(scope: Construct, id: string, props: ApiGatewayTo
 |putRecordsRequestModel?|[`api.ModelOptions`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-apigateway.ModelOptions.html)|API Gateway request model for the PutRecords action. If not provided, a default one will be created.|
 |existingStreamObj?|[`kinesis.Stream`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.Stream.html)|Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored.|
 |kinesisStreamProps?|[`kinesis.StreamProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kinesis.StreamProps.html)|Optional user-provided props to override the default props for the Kinesis stream.|
+|logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 
 ## Pattern Properties
 
@@ -141,6 +142,7 @@ class ApiGatewayToKinesisStreams(
         api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
         put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
@@ -152,6 +154,7 @@ class ApiGatewayToKinesisStreams(
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis Data Stream. Default: - Default properties are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         :param put_record_request_model: API Gateway request model for the PutRecord action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecord proxy single-record payload","type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
         :param put_record_request_template: API Gateway request template for the PutRecord action. If not provided, a default one will be used. Default: - { "StreamName": "${this.kinesisStream.streamName}", "Data": "$util.base64Encode($input.json('$.data'))", "PartitionKey": "$input.path('$.partitionKey')" }
         :param put_records_request_model: API Gateway request model for the PutRecords action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"], "properties":{"records":{"type":"array","items":{"type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
@@ -165,6 +168,7 @@ class ApiGatewayToKinesisStreams(
             api_gateway_props=api_gateway_props,
             existing_stream_obj=existing_stream_obj,
             kinesis_stream_props=kinesis_stream_props,
+            log_group_props=log_group_props,
             put_record_request_model=put_record_request_model,
             put_record_request_template=put_record_request_template,
             put_records_request_model=put_records_request_model,
@@ -206,6 +210,7 @@ class ApiGatewayToKinesisStreams(
         "api_gateway_props": "apiGatewayProps",
         "existing_stream_obj": "existingStreamObj",
         "kinesis_stream_props": "kinesisStreamProps",
+        "log_group_props": "logGroupProps",
         "put_record_request_model": "putRecordRequestModel",
         "put_record_request_template": "putRecordRequestTemplate",
         "put_records_request_model": "putRecordsRequestModel",
@@ -219,6 +224,7 @@ class ApiGatewayToKinesisStreamsProps:
         api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
         kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
         put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
         put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
@@ -228,6 +234,7 @@ class ApiGatewayToKinesisStreamsProps:
         :param api_gateway_props: Optional user-provided props to override the default props for the API Gateway. Default: - Default properties are used.
         :param existing_stream_obj: Existing instance of Kinesis Stream, if this is set then kinesisStreamProps is ignored. Default: - None
         :param kinesis_stream_props: Optional user-provided props to override the default props for the Kinesis Data Stream. Default: - Default properties are used.
+        :param log_group_props: User provided props to override the default props for the CloudWatchLogs LogGroup. Default: - Default props are used
         :param put_record_request_model: API Gateway request model for the PutRecord action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecord proxy single-record payload","type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}
         :param put_record_request_template: API Gateway request template for the PutRecord action. If not provided, a default one will be used. Default: - { "StreamName": "${this.kinesisStream.streamName}", "Data": "$util.base64Encode($input.json('$.data'))", "PartitionKey": "$input.path('$.partitionKey')" }
         :param put_records_request_model: API Gateway request model for the PutRecords action. If not provided, a default one will be created. Default: - {"$schema":"http://json-schema.org/draft-04/schema#","title":"PutRecords proxy payload data","type":"object","required":["records"], "properties":{"records":{"type":"array","items":{"type":"object", "required":["data","partitionKey"],"properties":{"data":{"type":"string"},"partitionKey":{"type":"string"}}}}}}
@@ -239,6 +246,8 @@ class ApiGatewayToKinesisStreamsProps:
             api_gateway_props = aws_cdk.aws_apigateway.RestApiProps(**api_gateway_props)
         if isinstance(kinesis_stream_props, dict):
             kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
+        if isinstance(log_group_props, dict):
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(put_record_request_model, dict):
             put_record_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_record_request_model)
         if isinstance(put_records_request_model, dict):
@@ -250,6 +259,8 @@ class ApiGatewayToKinesisStreamsProps:
             self._values["existing_stream_obj"] = existing_stream_obj
         if kinesis_stream_props is not None:
             self._values["kinesis_stream_props"] = kinesis_stream_props
+        if log_group_props is not None:
+            self._values["log_group_props"] = log_group_props
         if put_record_request_model is not None:
             self._values["put_record_request_model"] = put_record_request_model
         if put_record_request_template is not None:
@@ -286,6 +297,15 @@ class ApiGatewayToKinesisStreamsProps:
         result = self._values.get("kinesis_stream_props")
         return result
 
+    @builtins.property
+    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+        """User provided props to override the default props for the CloudWatchLogs LogGroup.
+
+        :default: - Default props are used
+        """
+        result = self._values.get("log_group_props")
+        return result
+
     @builtins.property
     def put_record_request_model(
         self,
